pub struct FanOutTask { /* private fields */ }Expand description
Composite task that executes multiple child tasks concurrently and aggregates results.
Implementations
Sourceimpl FanOutTask
impl FanOutTask
Sourcepub fn new(id: impl Into<String>, children: Vec<Arc<dyn Task>>) -> Arc<Self>
pub fn new(id: impl Into<String>, children: Vec<Arc<dyn Task>>) -> Arc<Self>
Create a new FanOutTask with an explicit id and a list of child tasks.
Sourcepub fn with_prefix(self: Arc<Self>, prefix: impl Into<String>) -> Arc<Self>
pub fn with_prefix(self: Arc<Self>, prefix: impl Into<String>) -> Arc<Self>
Set a context prefix for storing aggregated child results.
Aggregation keys will be written as <prefix>.<child_id>.<field>.
Sourcepub fn with_next_action(self: Arc<Self>, next: NextAction) -> Arc<Self>
pub fn with_next_action(self: Arc<Self>, next: NextAction) -> Arc<Self>
Override the NextAction returned by the FanOutTask (default: Continue).